@@ -1,9 +1,12 @@
 from datetime import datetime
+from pathlib import Path
 from typing import List, Union
 
 import dateutil.parser
+from emoji import is_emoji
 
 from csv2notion.csv_data import CSVData
+from csv2notion.notion_type_guess import is_url
 from csv2notion.utils import rand_id_list
 
 
@@ -34,8 +37,19 @@ def map_number(value: str) -> Union[int, float]:
     return float_value
 
 
-def schema_from_csv(csv_data: CSVData) -> dict:
-    columns = csv_data.keys()
+def map_icon(s: str) -> Union[str, Path]:
+    return s if is_url(s) or is_emoji(s) else Path(s)
+
+
+def map_image(s: str) -> Union[str, Path]:
+    return s if is_url(s) else Path(s)
+
+
+def schema_from_csv(csv_data: CSVData, skip_columns: List[str] = None) -> dict:
+    if skip_columns:
+        columns = [c for c in csv_data.keys() if c not in skip_columns]
+    else:
+        columns = csv_data.keys()
 
     schema_ids = rand_id_list(len(columns) - 1, 4)
 
